################
# main.py      #
# G.Desmeulles #
# 27/07/2022   #
# S2   IPI     #
################

#modules externes
import sys
import time
import select
import tty 
import termios

#mes modules
import Background 
import Animat

def init(data):
	
	#initialisation de la partie	
	data['timeStep']=0.2
	
	# creation des elements du jeu
	data['animat'] = Animat.create(color=3,
				direction="right",
				x=5.0,
				y=5.0,
				x_max=20.0,
				y_max=20.0,
				speed=3.0)

	data['background'] = Background.create("image.txt")

	# interaction clavier
	data['old_settings']= termios.tcgetattr(sys.stdin)
	tty.setcbreak(sys.stdin.fileno())

def move(data):
	#deplacement animat
	Animat.move(data['animat'],data['timeStep'])
	
def interact(data):

	#gestion des evenement clavier
	
	#si une touche est appuyee
	if isData():
		c = sys.stdin.read(1)
		if c == '\x1b':         # x1b is ESC
			quitGame(data)
		elif c=='c' :
			Animat.changeColor(data['animat'])
		elif c=='d' :
			Animat.changeDirection(data['animat'])
		
def isData():
	#recuperation evenement clavier
	return select.select([sys.stdin], [], [], 0) == ([sys.stdin], [], [])

def show(data):
	
	#rafraichissement de l'affichage
	
	#effacer la console
	sys.stdout.write("\033[1;1H")
	sys.stdout.write("\033[2J")

	#affichage des different element
	Background.show(data['background'])
	Animat.show(data['animat'])
	
	#restoration couleur 
	sys.stdout.write("\033[37m")
	sys.stdout.write("\033[40m")

	#deplacement curseur
	sys.stdout.write("\033[0;0H\n")


def run(data):
	
	#Boucle de simulation	
	while 1:
		interact(data)		
		move(data)
		show(data)
		time.sleep(data['timeStep'])

def quitGame(data):	
		
	#couleur white
	sys.stdout.write("\033[37m")
	sys.stdout.write("\033[40m")
	
	termios.tcsetattr(sys.stdin, termios.TCSADRAIN, data['old_settings'])
	sys.exit()

######################################
if __name__=="__main__":
	data={'animat':None,'background':None, 'timeStep':None,'old_settings':None}
	init(data)
	run(data)
	quitGame(data) #code mort



